@@ -108,7 +108,7 @@ types: dict[str, str] = {
     "AWS::Athena::PreparedStatement": "f136b10278378b55",
     "AWS::Athena::WorkGroup": "15b478b9836a0d48",
     "AWS::AuditManager::Assessment": "e446f275db12e7a4",
-    "AWS::AutoScaling::AutoScalingGroup": "1176577a6acfd8f9",
+    "AWS::AutoScaling::AutoScalingGroup": "8fe2b009cdacf409",
     "AWS::AutoScaling::LaunchConfiguration": "d4a1a18430ff4776",
     "AWS::AutoScaling::LifecycleHook": "95c6d4e044efc81a",
     "AWS::AutoScaling::ScalingPolicy": "3a71f2160c19e614",
@@ -262,18 +262,18 @@ types: dict[str, str] = {
     "AWS::DataBrew::Ruleset": "932632c822ce6169",
     "AWS::DataBrew::Schedule": "1995bc021a9e7e23",
     "AWS::DataPipeline::Pipeline": "f54867769cc566cf",
-    "AWS::DataSync::Agent": "733ace3e7eff9e68",
-    "AWS::DataSync::LocationAzureBlob": "02a252d30ebe9091",
-    "AWS::DataSync::LocationEFS": "dc695ceb626bd6aa",
-    "AWS::DataSync::LocationFSxLustre": "94324095d22e84c5",
-    "AWS::DataSync::LocationFSxONTAP": "fb2886550a94a821",
-    "AWS::DataSync::LocationFSxWindows": "7123c04a1159211f",
-    "AWS::DataSync::LocationHDFS": "9b0576d7bd1858ba",
-    "AWS::DataSync::LocationNFS": "bf12cdbf56d7c3b2",
-    "AWS::DataSync::LocationObjectStorage": "65e47a263206c90e",
-    "AWS::DataSync::LocationS3": "34db2462e6e07c08",
-    "AWS::DataSync::LocationSMB": "a045adab4853018c",
-    "AWS::DataSync::Task": "6a02fb3e9861f0e9",
+    "AWS::DataSync::Agent": "5f41806ea8ec42b9",
+    "AWS::DataSync::LocationAzureBlob": "d8a83e58123bc26d",
+    "AWS::DataSync::LocationEFS": "f74b4ff1503e9407",
+    "AWS::DataSync::LocationFSxLustre": "bf64014c70578e21",
+    "AWS::DataSync::LocationFSxONTAP": "f120a7ad0e329aaf",
+    "AWS::DataSync::LocationFSxWindows": "4fa3850617966c77",
+    "AWS::DataSync::LocationHDFS": "0639306ca013b8ec",
+    "AWS::DataSync::LocationNFS": "2659197742246dcd",
+    "AWS::DataSync::LocationObjectStorage": "a66b77a26a3e1747",
+    "AWS::DataSync::LocationS3": "0190e1a20831d5e0",
+    "AWS::DataSync::LocationSMB": "84f56a8c81ace8fd",
+    "AWS::DataSync::Task": "d896b335ffc11f10",
     "AWS::Detective::Graph": "dbed0b7e7b29e1e6",
     "AWS::Detective::MemberInvitation": "86355f574dcf77f5",
     "AWS::Detective::OrganizationAdmin": "28db50ef7caf9609",
@@ -285,7 +285,7 @@ types: dict[str, str] = {
     "AWS::DynamoDB::GlobalTable": "1789ed6c17b2b960",
     "AWS::DynamoDB::Table": "8e1902cddc19c9ad",
     "AWS::EC2::CapacityManagerDataExport": "eadbbd5d7fd8fd3c",
-    "AWS::EC2::CapacityReservation": "5b0dc1ffda2169f7",
+    "AWS::EC2::CapacityReservation": "d8685a879c65fa62",
     "AWS::EC2::CapacityReservationFleet": "3cec76abc326e6e7",
     "AWS::EC2::ClientVpnAuthorizationRule": "9dfbd181c3c5a54c",
     "AWS::EC2::ClientVpnEndpoint": "9927a4c168876daf",
@@ -308,7 +308,7 @@ types: dict[str, str] = {
     "AWS::EC2::IPAMResourceDiscovery": "694c0afb626c30d8",
     "AWS::EC2::IPAMResourceDiscoveryAssociation": "fde93486402ddbe5",
     "AWS::EC2::IPAMScope": "f1341090e0e57749",
-    "AWS::EC2::Instance": "51763c48d327df98",
+    "AWS::EC2::Instance": "a922ff4a1cb10687",
     "AWS::EC2::InstanceConnectEndpoint": "aff65ea38d1b25dc",
     "AWS::EC2::InternetGateway": "4c7c90cb3105c9d8",
     "AWS::EC2::IpPoolRouteTableAssociation": "071b5a1f00936f72",
@@ -320,7 +320,7 @@ types: dict[str, str] = {
     "AWS::EC2::LocalGatewayRouteTableVirtualInterfaceGroupAssociation": "632889615ea7dc14",
     "AWS::EC2::LocalGatewayVirtualInterface": "157dfe2a5a961bb9",
     "AWS::EC2::LocalGatewayVirtualInterfaceGroup": "1ed30b89e3e9b7ed",
-    "AWS::EC2::NatGateway": "bb97935c916b47f0",
+    "AWS::EC2::NatGateway": "28e80cb1fcf92145",
     "AWS::EC2::NetworkAcl": "41c7ec1cea436cd8",
     "AWS::EC2::NetworkAclEntry": "d4fc9ce8669023f0",
     "AWS::EC2::NetworkInsightsAccessScope": "f174ef9549ba3fd9",
@@ -399,8 +399,8 @@ types: dict[str, str] = {
     "AWS::ECR::RegistryScanningConfiguration": "68012043447b437a",
     "AWS::ECR::ReplicationConfiguration": "dc2a377f75525dd4",
     "AWS::ECR::Repository": "d569f41026af3be8",
-    "AWS::ECR::RepositoryCreationTemplate": "260745c34d057c07",
-    "AWS::ECR::SigningConfiguration": "2134ed8fb7551261",
+    "AWS::ECR::RepositoryCreationTemplate": "38e9548ebe8ec1f5",
+    "AWS::ECR::SigningConfiguration": "c502bcdb31b67cc1",
     "AWS::ECS::CapacityProvider": "5804cc1956f638f2",
     "AWS::ECS::Cluster": "3990111074eac8be",
     "AWS::ECS::ClusterCapacityProviderAssociations": "4b512d1fe30ffdd3",
@@ -430,6 +430,7 @@ types: dict[str, str] = {
     "AWS::EMR::WALWorkspace": "1acf5569fff4fcbe",
     "AWS::EMRContainers::VirtualCluster": "d56c1799bc259539",
     "AWS::EMRServerless::Application": "b8f0bd50831c9f1e",
+    "AWS::EVS::Environment": "8cbba6115db38908",
     "AWS::ElastiCache::CacheCluster": "1220b6bbd633ae68",
     "AWS::ElastiCache::GlobalReplicationGroup": "2af3062bf5b2cf7f",
     "AWS::ElastiCache::ParameterGroup": "b0e1dec3cd05f739",
@@ -466,7 +467,7 @@ types: dict[str, str] = {
     "AWS::Events::Rule": "4b8efe4a7f81f66f",
     "AWS::FIS::ExperimentTemplate": "0277c14e1157435b",
     "AWS::FIS::TargetAccountConfiguration": "c2959eedf6398b2a",
-    "AWS::FMS::NotificationChannel": "622ce9589b28d75d",
+    "AWS::FMS::NotificationChannel": "8562504583cd6ad4",
     "AWS::FMS::Policy": "3d3868b1e974d27b",
     "AWS::FMS::ResourceSet": "6fb04db2dcf50bf8",
     "AWS::FSx::DataRepositoryAssociation": "2c944a4b33c2d639",
@@ -603,7 +604,7 @@ types: dict[str, str] = {
     "AWS::KMS::Alias": "28f10f922a4d194f",
     "AWS::KMS::Key": "c70e396ee12ddb65",
     "AWS::KMS::ReplicaKey": "903f43e74c8d8853",
-    "AWS::KafkaConnect::Connector": "b6f9713f56922d8c",
+    "AWS::KafkaConnect::Connector": "08b81c973eb812dd",
     "AWS::KafkaConnect::CustomPlugin": "f04fc57818e8ddb4",
     "AWS::KafkaConnect::WorkerConfiguration": "8a9b885926e8a00c",
     "AWS::Kinesis::ResourcePolicy": "39996915810e234a",
@@ -650,7 +651,7 @@ types: dict[str, str] = {
     "AWS::Logs::QueryDefinition": "7b82b12db189c1d9",
     "AWS::Logs::ResourcePolicy": "d7898253a7730ac3",
     "AWS::Logs::SubscriptionFilter": "57635d7dc5bd3e61",
-    "AWS::Logs::Transformer": "4d1796b2fa0445b0",
+    "AWS::Logs::Transformer": "66b4b09c596d83c0",
     "AWS::M2::Application": "7c1b78891b93a215",
     "AWS::M2::Deployment": "a4f5b6e67e1de730",
     "AWS::M2::Environment": "556251194fbbcc67",
@@ -728,9 +729,9 @@ types: dict[str, str] = {
     "AWS::Oam::Link": "4d4e114e0f615d82",
     "AWS::Oam::Sink": "81957ea027e4c201",
     "AWS::ObservabilityAdmin::OrganizationCentralizationRule": "6921de30f2cef3a3",
-    "AWS::ObservabilityAdmin::OrganizationTelemetryRule": "225b0189a145b2e5",
+    "AWS::ObservabilityAdmin::OrganizationTelemetryRule": "4f702fc11306cf74",
     "AWS::ObservabilityAdmin::TelemetryPipelines": "1acc5affc6615ad2",
-    "AWS::ObservabilityAdmin::TelemetryRule": "fb51013ab5f3afe7",
+    "AWS::ObservabilityAdmin::TelemetryRule": "a54d5e794c37e6c1",
     "AWS::OpenSearchServerless::AccessPolicy": "ec7a348a493d8c4f",
     "AWS::OpenSearchServerless::Collection": "be876510f965bd06",
     "AWS::OpenSearchServerless::Index": "fcc40949c8a1e83a",
@@ -832,11 +833,11 @@ types: dict[str, str] = {
     "AWS::S3::AccessGrantsInstance": "05d3e874b43bbad8",
     "AWS::S3::AccessGrantsLocation": "3a7be1727f630029",
     "AWS::S3::AccessPoint": "e8b95810dd8d6917",
-    "AWS::S3::Bucket": "1aa877c9b86f9e89",
+    "AWS::S3::Bucket": "bc2a891a463ee5ee",
     "AWS::S3::BucketPolicy": "38ad5b8bd8062535",
     "AWS::S3::MultiRegionAccessPoint": "193323be1bf2dac0",
     "AWS::S3::MultiRegionAccessPointPolicy": "7ac84076052ddd16",
-    "AWS::S3::StorageLens": "bb038f16e3dd3fd9",
+    "AWS::S3::StorageLens": "842abc50870a3bcf",
     "AWS::S3::StorageLensGroup": "a48c03e67d334c14",
     "AWS::S3ObjectLambda::AccessPoint": "2d6b2b82a9508114",
     "AWS::S3ObjectLambda::AccessPointPolicy": "fd6328c6c782223a",
@@ -868,6 +869,7 @@ types: dict[str, str] = {
     "AWS::SES::ReceiptRule": "6641e8f6c31a50e6",
     "AWS::SES::ReceiptRuleSet": "79ecdd974ccaeb6a",
     "AWS::SES::Template": "20af669206370beb",
+    "AWS::SES::Tenant": "0c003f20faaf4446",
     "AWS::SES::VdmAttributes": "15df0379061c0489",
     "AWS::SMSVOICE::ConfigurationSet": "2bdda88e956e2a26",
     "AWS::SMSVOICE::OptOutList": "005f2438fbf815f8",
@@ -886,8 +888,8 @@ types: dict[str, str] = {
     "AWS::SSM::Association": "ad263c9023f92e0c",
     "AWS::SSM::Document": "8b3a8b629d6edee1",
     "AWS::SSM::MaintenanceWindow": "54b31dcf040d1e3b",
-    "AWS::SSM::MaintenanceWindowTarget": "67da7a687adc34fb",
-    "AWS::SSM::MaintenanceWindowTask": "bdd479736cab2d77",
+    "AWS::SSM::MaintenanceWindowTarget": "16bcb928c1d2233d",
+    "AWS::SSM::MaintenanceWindowTask": "ce68f32e2ef0a575",
     "AWS::SSM::Parameter": "c247b226112c5ae5",
     "AWS::SSM::PatchBaseline": "43cce065b6753223",
     "AWS::SSM::ResourceDataSync": "f92ce1aa6674b7f2",
@@ -909,7 +911,7 @@ types: dict[str, str] = {
     "AWS::SSO::PermissionSet": "e4212a96dd4b627d",
     "AWS::SageMaker::App": "a2a6c6e24ea97c09",
     "AWS::SageMaker::AppImageConfig": "c4676a45bc3fb01f",
-    "AWS::SageMaker::Cluster": "6c22689b2b894002",
+    "AWS::SageMaker::Cluster": "c5fd402192f22c50",
     "AWS::SageMaker::CodeRepository": "d59f5cf4521ff1c2",
     "AWS::SageMaker::DataQualityJobDefinition": "aa9b4c65d2154f84",
     "AWS::SageMaker::Domain": "d0c9a5567721ed89",
